import string
import random
import jwt
try:
    from django.conf import settings
except Exception as e:
    pass


def get_code(digits_only=False, length=6):
    # length of the string.
    S = length
    # call random.choices() string module to find the string in Uppercase + numeric data.
    ran = ''.join(random.choices(string.ascii_uppercase + string.digits, k=S))

    if digits_only:
        ran = ''.join(random.choices(string.digits, k=S))

    return ran


def is_authenticated(access_token):
    if access_token is not None:
        try:
            # _, token = access_token.split(' ')
            decoded = jwt.decode(access_token, options={
                                 "verify_signature": False})
            OAUTH2_SCOPE = getattr(settings, 'OAUTH2_SCOPE', None)

            if OAUTH2_SCOPE in decoded.get('scope', []):
                return True
        except Exception as e:
            print(f'is_authenticated: {e}')
            return False

    return False



# Generated by Django 3.2.5 on 2022-11-08 13:16

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bank_sync', '0002_alter_callbacks_reference'),
    ]

    operations = [
        migrations.CreateModel(
            name='RequestLogs',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('ip', models.CharField(max_length=50)),
                ('method', models.CharField(max_length=10)),
                ('path', models.CharField(max_length=100)),
                ('content_type', models.CharField(max_length=50)),
                ('content_params', models.JSONField(default=dict)),
                ('body', models.JSONField(default=dict)),
                ('headers', models.JSONField(default=dict)),
                ('user', models.CharField(max_length=100)),
            ],
        ),
    ]
